Method: TD::ClientMethods#edit_message_live_location

Defined in:
lib/tdlib/client_methods.rb

#edit_message_live_location(chat_id, message_id, reply_markup, location = nil) ⇒ TD::Types::Message

Edits the message content of a live location. Messages can be edited for a limited period of time specified in the live location. Returns the edited message after the edit is completed on the server side.

Parameters:

  • chat_id (Integer)

    The chat the message belongs to.

  • message_id (Integer)

    Identifier of the message.

  • reply_markup (TD::Types::ReplyMarkup)

    The new message reply markup; for bots only.

  • location (TD::Types::Location, nil) (defaults to: nil)

    New location content of the message; may be null. Pass null to stop sharing the live location.

Returns:



1004
1005
1006
1007
1008
1009
1010
# File 'lib/tdlib/client_methods.rb', line 1004

def edit_message_live_location(chat_id, message_id, reply_markup, location = nil)
  broadcast('@type'        => 'editMessageLiveLocation',
            'chat_id'      => chat_id,
            'message_id'   => message_id,
            'reply_markup' => reply_markup,
            'location'     => location)
end