Class: TD::Types::AuthorizationState::WaitCode
- Inherits:
-
TD::Types::AuthorizationState
- Object
- Dry::Struct
- Base
- TD::Types::AuthorizationState
- TD::Types::AuthorizationState::WaitCode
- Defined in:
- lib/tdlib/types/authorization_state/wait_code.rb
Overview
TDLib needs the user's authentication code to finalize authorization.
Instance Attribute Summary collapse
-
#code_info ⇒ TD::Types::AuthenticationCodeInfo
Information about the authorization code that was sent.
-
#is_registered ⇒ Boolean
True, if the user is already registered.
-
#terms_of_service ⇒ TD::Types::TermsOfService?
Telegram terms of service, which should be accepted before user can continue registration; may be null.
Method Summary
Methods inherited from Base
Instance Attribute Details
#code_info ⇒ TD::Types::AuthenticationCodeInfo
Information about the authorization code that was sent.
8 9 10 |
# File 'lib/tdlib/types/authorization_state/wait_code.rb', line 8 def code_info @code_info end |
#is_registered ⇒ Boolean
True, if the user is already registered.
8 9 10 |
# File 'lib/tdlib/types/authorization_state/wait_code.rb', line 8 def is_registered @is_registered end |
#terms_of_service ⇒ TD::Types::TermsOfService?
Telegram terms of service, which should be accepted before user can continue registration; may be null.
8 9 10 |
# File 'lib/tdlib/types/authorization_state/wait_code.rb', line 8 def terms_of_service @terms_of_service end |