Class: TD::Types::BackgroundType::Pattern

Inherits:
TD::Types::BackgroundType show all
Defined in:
lib/tdlib/types/background_type/pattern.rb

Overview

A PNG pattern to be combined with the color chosen by the user.

Instance Attribute Summary collapse

Method Summary

Methods inherited from TD::Types::Base

#to_hash, #to_json

Instance Attribute Details

#colorInteger

Main color of the background in RGB24 format.

Returns:

  • (Integer)

    the current value of color



7
8
9
# File 'lib/tdlib/types/background_type/pattern.rb', line 7

def color
  @color
end

#intensityInteger

Intensity of the pattern when it is shown above the main background color, 0-100.

Returns:

  • (Integer)

    the current value of intensity



7
8
9
# File 'lib/tdlib/types/background_type/pattern.rb', line 7

def intensity
  @intensity
end

#is_movingBoolean

True, if the background needs to be slightly moved when device is rotated.

Returns:

  • (Boolean)

    the current value of is_moving



7
8
9
# File 'lib/tdlib/types/background_type/pattern.rb', line 7

def is_moving
  @is_moving
end