Class: TD::Types::BasicGroup

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/basic_group.rb

Overview

Represents a basic group of 0-200 users (must be upgraded to a supergroup to accommodate more than 200 users).

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#everyone_is_administratorBoolean

True, if all members have been granted administrator rights in the group.

Returns:

  • (Boolean)

    the current value of everyone_is_administrator



10
11
12
# File 'lib/tdlib/types/basic_group.rb', line 10

def everyone_is_administrator
  @everyone_is_administrator
end

#idInteger

Group identifier.

Returns:

  • (Integer)

    the current value of id



10
11
12
# File 'lib/tdlib/types/basic_group.rb', line 10

def id
  @id
end

#is_activeBoolean

True, if the group is active.

Returns:

  • (Boolean)

    the current value of is_active



10
11
12
# File 'lib/tdlib/types/basic_group.rb', line 10

def is_active
  @is_active
end

#member_countInteger

Number of members in the group.

Returns:

  • (Integer)

    the current value of member_count



10
11
12
# File 'lib/tdlib/types/basic_group.rb', line 10

def member_count
  @member_count
end

#statusTD::Types::ChatMemberStatus

Status of the current user in the group.

Returns:



10
11
12
# File 'lib/tdlib/types/basic_group.rb', line 10

def status
  @status
end

#upgraded_to_supergroup_idInteger

Identifier of the supergroup to which this group was upgraded; 0 if none.

Returns:

  • (Integer)

    the current value of upgraded_to_supergroup_id



10
11
12
# File 'lib/tdlib/types/basic_group.rb', line 10

def upgraded_to_supergroup_id
  @upgraded_to_supergroup_id
end