Class: TD::Types::ChatNotificationSettings

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/chat_notification_settings.rb

Overview

Contains information about notification settings for a chat.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#disable_mention_notifications ⇒ Boolean

If true, notifications for messages with mentions will be created as for an ordinary unread message.

Returns:

  • the current value of disable_mention_notifications



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def disable_mention_notifications
  @disable_mention_notifications
end

#disable_pinned_message_notifications ⇒ Boolean

If true, notifications for incoming pinned messages will be created as for an ordinary unread message.

Returns:

  • the current value of disable_pinned_message_notifications



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def disable_pinned_message_notifications
  @disable_pinned_message_notifications
end

#mute_for ⇒ Integer

Time left before notifications will be unmuted, in seconds.

Returns:

  • the current value of mute_for



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def mute_for
  @mute_for
end

#show_preview ⇒ Boolean

True, if message content should be displayed in notifications.

Returns:

  • the current value of show_preview



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def show_preview
  @show_preview
end

#sound ⇒ String

The name of an audio file to be used for notification sounds; only applies to iOS applications.

Returns:

  • the current value of sound



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def sound
  @sound
end

#use_default_disable_mention_notifications ⇒ Boolean

If true, disable_mention_notifications is ignored and the value for the relevant type of chat is used instead.

Returns:

  • the current value of use_default_disable_mention_notifications



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def use_default_disable_mention_notifications
  @use_default_disable_mention_notifications
end

#use_default_disable_pinned_message_notifications ⇒ Boolean

If true, disable_pinned_message_notifications is ignored and the value for the relevant type of chat is used instead.

Returns:

  • the current value of use_default_disable_pinned_message_notifications



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def use_default_disable_pinned_message_notifications
  @use_default_disable_pinned_message_notifications
end

#use_default_mute_for ⇒ Boolean

If true, mute_for is ignored and the value for the relevant type of chat is used instead.

Returns:

  • the current value of use_default_mute_for



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def use_default_mute_for
  @use_default_mute_for
end

#use_default_show_preview ⇒ Boolean

If true, show_preview is ignored and the value for the relevant type of chat is used instead.

Returns:

  • the current value of use_default_show_preview



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def use_default_show_preview
  @use_default_show_preview
end

#use_default_sound ⇒ Boolean

If true, sound is ignored and the value for the relevant type of chat is used instead.

Returns:

  • the current value of use_default_sound



22
23
24
# File 'lib/tdlib/types/chat_notification_settings.rb', line 22

def use_default_sound
  @use_default_sound
end