Class: TD::Types::InputMessageContent::Forwarded

Inherits:
TD::Types::InputMessageContent show all
Defined in:
lib/tdlib/types/input_message_content/forwarded.rb

Overview

A forwarded message.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#from_chat_idInteger

Identifier for the chat this forwarded message came from.

Returns:

  • (Integer)

    the current value of from_chat_id



13
14
15
# File 'lib/tdlib/types/input_message_content/forwarded.rb', line 13

def from_chat_id
  @from_chat_id
end

#in_game_shareBoolean

True, if a game message should be shared within a launched game; applies only to game messages.

Returns:

  • (Boolean)

    the current value of in_game_share



13
14
15
# File 'lib/tdlib/types/input_message_content/forwarded.rb', line 13

def in_game_share
  @in_game_share
end

#message_idInteger

Identifier of the message to forward.

Returns:

  • (Integer)

    the current value of message_id



13
14
15
# File 'lib/tdlib/types/input_message_content/forwarded.rb', line 13

def message_id
  @message_id
end

#remove_captionBoolean

True, if media caption of the message copy needs to be removed. Ignored if send_copy is false.

Returns:

  • (Boolean)

    the current value of remove_caption



13
14
15
# File 'lib/tdlib/types/input_message_content/forwarded.rb', line 13

def remove_caption
  @remove_caption
end

#send_copyBoolean

True, if content of the message needs to be copied without a link to the original message. Always true if the message is forwarded to a secret chat.

Returns:

  • (Boolean)

    the current value of send_copy



13
14
15
# File 'lib/tdlib/types/input_message_content/forwarded.rb', line 13

def send_copy
  @send_copy
end