Class: TD::Types::InputMessageContent::Invoice

Inherits:
TD::Types::InputMessageContent show all
Defined in:
lib/tdlib/types/input_message_content/invoice.rb

Overview

A message with an invoice; can be used only by bots and only in private chats.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#description ⇒ String

Product description; 0-255 characters.

Returns:

  • (String) —

    the current value of description



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def description
  @description
end

#invoice ⇒ TD::Types::Invoice

Invoice.

Returns:



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def invoice
  @invoice
end

#payload ⇒ String

The invoice payload.

Returns:

  • (String) —

    the current value of payload



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def payload
  @payload
end

#photo_height ⇒ Integer

Product photo height.

Returns:

  • (Integer) —

    the current value of photo_height



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def photo_height
  @photo_height
end

#photo_size ⇒ Integer

Product photo size.

Returns:

  • (Integer) —

    the current value of photo_size



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def photo_size
  @photo_size
end

#photo_url ⇒ String?

Product photo URL; optional.

Returns:

  • (String, nil) —

    the current value of photo_url



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def photo_url
  @photo_url
end

#photo_width ⇒ Integer

Product photo width.

Returns:

  • (Integer) —

    the current value of photo_width



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def photo_width
  @photo_width
end

#provider_data ⇒ String

JSON-encoded data about the invoice, which will be shared with the payment provider.

Returns:

  • (String) —

    the current value of provider_data



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def provider_data
  @provider_data
end

#provider_token ⇒ String

Payment provider token.

Returns:

  • (String) —

    the current value of provider_token



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def provider_token
  @provider_token
end

#start_parameter ⇒ String

Unique invoice bot start_parameter for the generation of this invoice.

Returns:

  • (String) —

    the current value of start_parameter



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def start_parameter
  @start_parameter
end

#title ⇒ String

Product title; 1-32 characters.

Returns:

  • (String) —

    the current value of title



15
16
17
# File 'lib/tdlib/types/input_message_content/invoice.rb', line 15

def title
  @title
end