Class: TD::Types::MessageForwardOrigin::Channel

Inherits:
TD::Types::MessageForwardOrigin show all
Defined in:
lib/tdlib/types/message_forward_origin/channel.rb

Overview

The message was originally a post in a channel.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#author_signature ⇒ String

Original post author signature.

Returns:

  • (String) —

    the current value of author_signature



7
8
9
# File 'lib/tdlib/types/message_forward_origin/channel.rb', line 7

def author_signature
  @author_signature
end

#chat_id ⇒ Integer

Identifier of the chat from which the message was originally forwarded.

Returns:

  • (Integer) —

    the current value of chat_id



7
8
9
# File 'lib/tdlib/types/message_forward_origin/channel.rb', line 7

def chat_id
  @chat_id
end

#message_id ⇒ Integer

Message identifier of the original message; 0 if unknown.

Returns:

  • (Integer) —

    the current value of message_id



7
8
9
# File 'lib/tdlib/types/message_forward_origin/channel.rb', line 7

def message_id
  @message_id
end