Class: TD::Types::PassportElementErrorSource::TranslationFile

Inherits:
TD::Types::PassportElementErrorSource show all
Defined in:
lib/tdlib/types/passport_element_error_source/translation_file.rb

Overview

One of files with the translation of the document contains an error. The error will be considered resolved when the file changes.

Method Summary

Methods inherited from Base

#to_hash, #to_json