Class: TD::Types::ScopeNotificationSettings

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/scope_notification_settings.rb

Overview

Contains information about notification settings for several chats.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#disable_mention_notifications ⇒ Boolean

True, if notifications for messages with mentions will be created as for an ordinary unread message.

Returns:

  • (Boolean) —

    the current value of disable_mention_notifications



12
13
14
# File 'lib/tdlib/types/scope_notification_settings.rb', line 12

def disable_mention_notifications
  @disable_mention_notifications
end

#disable_pinned_message_notifications ⇒ Boolean

True, if notifications for incoming pinned messages will be created as for an ordinary unread message.

Returns:

  • (Boolean) —

    the current value of disable_pinned_message_notifications



12
13
14
# File 'lib/tdlib/types/scope_notification_settings.rb', line 12

def disable_pinned_message_notifications
  @disable_pinned_message_notifications
end

#mute_for ⇒ Integer

Time left before notifications will be unmuted, in seconds.

Returns:

  • (Integer) —

    the current value of mute_for



12
13
14
# File 'lib/tdlib/types/scope_notification_settings.rb', line 12

def mute_for
  @mute_for
end

#show_preview ⇒ Boolean

True, if message content should be displayed in notifications.

Returns:

  • (Boolean) —

    the current value of show_preview



12
13
14
# File 'lib/tdlib/types/scope_notification_settings.rb', line 12

def show_preview
  @show_preview
end

#sound ⇒ String

The name of an audio file to be used for notification sounds; only applies to iOS applications.

Returns:

  • (String) —

    the current value of sound



12
13
14
# File 'lib/tdlib/types/scope_notification_settings.rb', line 12

def sound
  @sound
end