Class: TD::Types::Sticker
- Defined in:
- lib/tdlib/types/sticker.rb
Overview
Describes a sticker.
Instance Attribute Summary collapse
-
#emoji ⇒ String
Emoji corresponding to the sticker.
-
#height ⇒ Integer
Sticker height; as defined by the sender.
-
#is_mask ⇒ Boolean
True, if the sticker is a mask.
-
#mask_position ⇒ TD::Types::MaskPosition?
Position where the mask should be placed; may be null.
-
#set_id ⇒ Integer
The identifier of the sticker set to which the sticker belongs; 0 if none.
-
#sticker ⇒ TD::Types::File
File containing the sticker.
-
#thumbnail ⇒ TD::Types::PhotoSize?
Sticker thumbnail in WEBP or JPEG format; may be null.
-
#width ⇒ Integer
Sticker width; as defined by the sender.
Method Summary
Methods inherited from Base
Instance Attribute Details
#emoji ⇒ String
Emoji corresponding to the sticker.
12 13 14 |
# File 'lib/tdlib/types/sticker.rb', line 12 def emoji @emoji end |
#height ⇒ Integer
Sticker height; as defined by the sender.
12 13 14 |
# File 'lib/tdlib/types/sticker.rb', line 12 def height @height end |
#is_mask ⇒ Boolean
True, if the sticker is a mask.
12 13 14 |
# File 'lib/tdlib/types/sticker.rb', line 12 def is_mask @is_mask end |
#mask_position ⇒ TD::Types::MaskPosition?
Position where the mask should be placed; may be null.
12 13 14 |
# File 'lib/tdlib/types/sticker.rb', line 12 def mask_position @mask_position end |
#set_id ⇒ Integer
The identifier of the sticker set to which the sticker belongs; 0 if none.
12 13 14 |
# File 'lib/tdlib/types/sticker.rb', line 12 def set_id @set_id end |
#sticker ⇒ TD::Types::File
File containing the sticker.
12 13 14 |
# File 'lib/tdlib/types/sticker.rb', line 12 def sticker @sticker end |
#thumbnail ⇒ TD::Types::PhotoSize?
Sticker thumbnail in WEBP or JPEG format; may be null.
12 13 14 |
# File 'lib/tdlib/types/sticker.rb', line 12 def thumbnail @thumbnail end |
#width ⇒ Integer
Sticker width; as defined by the sender.
12 13 14 |
# File 'lib/tdlib/types/sticker.rb', line 12 def width @width end |