Class: TD::Types::StickerSet
- Defined in:
- lib/tdlib/types/sticker_set.rb
Overview
Represents a sticker set.
Instance Attribute Summary collapse
-
#emojis ⇒ Array<TD::Types::StickerEmojis>
A list of emoji corresponding to the stickers in the same order.
-
#id ⇒ Integer
Identifier of the sticker set.
-
#is_archived ⇒ Boolean
True, if the sticker set has been archived.
-
#is_installed ⇒ Boolean
True, if the sticker set has been installed by the current user.
-
#is_masks ⇒ Boolean
True, if the stickers in the set are masks.
-
#is_official ⇒ Boolean
True, if the sticker set is official.
-
#is_viewed ⇒ Boolean
True for already viewed trending sticker sets.
-
#name ⇒ String
Name of the sticker set.
-
#stickers ⇒ Array<TD::Types::Sticker>
List of stickers in this set.
-
#title ⇒ String
Title of the sticker set.
Method Summary
Methods inherited from Base
Instance Attribute Details
#emojis ⇒ Array<TD::Types::StickerEmojis>
A list of emoji corresponding to the stickers in the same order.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def emojis @emojis end |
#id ⇒ Integer
Identifier of the sticker set.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def id @id end |
#is_archived ⇒ Boolean
True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def is_archived @is_archived end |
#is_installed ⇒ Boolean
True, if the sticker set has been installed by the current user.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def is_installed @is_installed end |
#is_masks ⇒ Boolean
True, if the stickers in the set are masks.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def is_masks @is_masks end |
#is_official ⇒ Boolean
True, if the sticker set is official.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def is_official @is_official end |
#is_viewed ⇒ Boolean
True for already viewed trending sticker sets.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def is_viewed @is_viewed end |
#name ⇒ String
Name of the sticker set.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def name @name end |
#stickers ⇒ Array<TD::Types::Sticker>
List of stickers in this set.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def stickers @stickers end |
#title ⇒ String
Title of the sticker set.
15 16 17 |
# File 'lib/tdlib/types/sticker_set.rb', line 15 def title @title end |