Class: TD::Types::Update::ActiveNotifications
- Inherits:
-
TD::Types::Update
- Object
- Dry::Struct
- Base
- TD::Types::Update
- TD::Types::Update::ActiveNotifications
- Defined in:
- lib/tdlib/types/update/active_notifications.rb
Overview
Contains active notifications that was shown on previous application launches. This update is sent only if a message database is used. In that case it comes once before any updateNotification and updateNotificationGroup update.
Instance Attribute Summary collapse
-
#groups ⇒ Array<TD::Types::NotificationGroup>
Lists of active notification groups.
Method Summary
Methods inherited from Base
Instance Attribute Details
#groups ⇒ Array<TD::Types::NotificationGroup>
Lists of active notification groups.
7 8 9 |
# File 'lib/tdlib/types/update/active_notifications.rb', line 7 def groups @groups end |