Class: TD::Types::Update::UnreadChatCount

Inherits:
TD::Types::Update show all
Defined in:
lib/tdlib/types/update/unread_chat_count.rb

Overview

Number of unread chats, i.e. with unread messages or marked as unread, has changed. This update is sent only if a message database is used.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#marked_as_unread_countInteger

Total number of chats marked as unread.

Returns:

  • (Integer)

    the current value of marked_as_unread_count



10
11
12
# File 'lib/tdlib/types/update/unread_chat_count.rb', line 10

def marked_as_unread_count
  @marked_as_unread_count
end

#marked_as_unread_unmuted_countInteger

Total number of unmuted chats marked as unread.

Returns:

  • (Integer)

    the current value of marked_as_unread_unmuted_count



10
11
12
# File 'lib/tdlib/types/update/unread_chat_count.rb', line 10

def marked_as_unread_unmuted_count
  @marked_as_unread_unmuted_count
end

#unread_countInteger

Total number of unread chats.

Returns:

  • (Integer)

    the current value of unread_count



10
11
12
# File 'lib/tdlib/types/update/unread_chat_count.rb', line 10

def unread_count
  @unread_count
end

#unread_unmuted_countInteger

Total number of unread unmuted chats.

Returns:

  • (Integer)

    the current value of unread_unmuted_count



10
11
12
# File 'lib/tdlib/types/update/unread_chat_count.rb', line 10

def unread_unmuted_count
  @unread_unmuted_count
end