Class: TD::Types::UserFullInfo

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/user_full_info.rb

Overview

Contains full information about a user (except the full list of profile photos).

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#bioString

A short user bio.

Returns:

  • (String)

    the current value of bio



14
15
16
# File 'lib/tdlib/types/user_full_info.rb', line 14

def bio
  @bio
end

#bot_infoTD::Types::BotInfo?

If the user is a bot, information about the bot; may be null.

Returns:



14
15
16
# File 'lib/tdlib/types/user_full_info.rb', line 14

def bot_info
  @bot_info
end

#can_be_calledBoolean

True, if the user can be called.

Returns:

  • (Boolean)

    the current value of can_be_called



14
15
16
# File 'lib/tdlib/types/user_full_info.rb', line 14

def can_be_called
  @can_be_called
end

#group_in_common_countInteger

Number of group chats where both the other user and the current user are a member; 0 for the current user.

Returns:

  • (Integer)

    the current value of group_in_common_count



14
15
16
# File 'lib/tdlib/types/user_full_info.rb', line 14

def group_in_common_count
  @group_in_common_count
end

#has_private_callsBoolean

True, if the user can't be called due to their privacy settings.

Returns:

  • (Boolean)

    the current value of has_private_calls



14
15
16
# File 'lib/tdlib/types/user_full_info.rb', line 14

def has_private_calls
  @has_private_calls
end

#is_blockedBoolean

True, if the user is blacklisted by the current user.

Returns:

  • (Boolean)

    the current value of is_blocked



14
15
16
# File 'lib/tdlib/types/user_full_info.rb', line 14

def is_blocked
  @is_blocked
end

#need_phone_number_privacy_exceptionBoolean

True, if the current user needs to explicitly allow to share their phone number with the user when the method addContact is used.

Returns:

  • (Boolean)

    the current value of need_phone_number_privacy_exception



14
15
16
# File 'lib/tdlib/types/user_full_info.rb', line 14

def need_phone_number_privacy_exception
  @need_phone_number_privacy_exception
end

#share_textString

For bots, the text that is included with the link when users share the bot.

Returns:

  • (String)

    the current value of share_text



14
15
16
# File 'lib/tdlib/types/user_full_info.rb', line 14

def share_text
  @share_text
end