Method: TD::ClientMethods#edit_message_live_location
- Defined in:
- lib/tdlib/client_methods.rb
#edit_message_live_location(chat_id, message_id, reply_markup, location = nil) ⇒ TD::Types::Message
Edits the message content of a live location. Messages can be edited for a limited period of time specified in the live location. Returns the edited message after the edit is completed on the server side.
1004 1005 1006 1007 1008 1009 1010 |
# File 'lib/tdlib/client_methods.rb', line 1004 def (chat_id, , reply_markup, location = nil) broadcast('@type' => 'editMessageLiveLocation', 'chat_id' => chat_id, 'message_id' => , 'reply_markup' => reply_markup, 'location' => location) end |