Method: TD::ClientMethods#open_chat
- Defined in:
- lib/tdlib/client_methods.rb
#open_chat(chat_id) ⇒ TD::Types::Ok
Informs TDLib that the chat is opened by the user. Many useful activities depend on the chat being opened or closed (e.g., in supergroups and channels all updates are received only for opened chats).
2444 2445 2446 2447 |
# File 'lib/tdlib/client_methods.rb', line 2444 def open_chat(chat_id) broadcast('@type' => 'openChat', 'chat_id' => chat_id) end |