Method: TD::ClientMethods#view_messages
- Defined in:
- lib/tdlib/client_methods.rb
#view_messages(chat_id, message_ids, force_read) ⇒ TD::Types::Ok
Informs TDLib that messages are being viewed by the user. Many useful activities depend on whether the messages are currently being viewed or not (e.g., marking messages as read, incrementing a view counter, updating a view counter, removing deleted messages in supergroups and channels).
4214 4215 4216 4217 4218 4219 |
# File 'lib/tdlib/client_methods.rb', line 4214 def (chat_id, , force_read) broadcast('@type' => 'viewMessages', 'chat_id' => chat_id, 'message_ids' => , 'force_read' => force_read) end |