Class: TD::Types::BackgroundType::Pattern
- Inherits:
-
TD::Types::BackgroundType
- Object
- Dry::Struct
- TD::Types::Base
- TD::Types::BackgroundType
- TD::Types::BackgroundType::Pattern
- Defined in:
- lib/tdlib/types/background_type/pattern.rb
Overview
A PNG pattern to be combined with the color chosen by the user.
Instance Attribute Summary collapse
-
#color ⇒ Integer
Main color of the background in RGB24 format.
-
#intensity ⇒ Integer
Intensity of the pattern when it is shown above the main background color, 0-100.
-
#is_moving ⇒ Boolean
True, if the background needs to be slightly moved when device is rotated.
Method Summary
Methods inherited from TD::Types::Base
Instance Attribute Details
#color ⇒ Integer
Main color of the background in RGB24 format.
7 8 9 |
# File 'lib/tdlib/types/background_type/pattern.rb', line 7 def color @color end |
#intensity ⇒ Integer
Intensity of the pattern when it is shown above the main background color, 0-100.
7 8 9 |
# File 'lib/tdlib/types/background_type/pattern.rb', line 7 def intensity @intensity end |
#is_moving ⇒ Boolean
True, if the background needs to be slightly moved when device is rotated.
7 8 9 |
# File 'lib/tdlib/types/background_type/pattern.rb', line 7 def is_moving @is_moving end |