Class: TD::Types::UserFullInfo
- Defined in:
- lib/tdlib/types/user_full_info.rb
Overview
Contains full information about a user (except the full list of profile photos).
Instance Attribute Summary collapse
-
#bio ⇒ String
A short user bio.
-
#bot_info ⇒ TD::Types::BotInfo?
If the user is a bot, information about the bot; may be null.
-
#can_be_called ⇒ Boolean
True, if the user can be called.
-
#group_in_common_count ⇒ Integer
Number of group chats where both the other user and the current user are a member; 0 for the current user.
-
#has_private_calls ⇒ Boolean
True, if the user can't be called due to their privacy settings.
-
#is_blocked ⇒ Boolean
True, if the user is blacklisted by the current user.
-
#need_phone_number_privacy_exception ⇒ Boolean
True, if the current user needs to explicitly allow to share their phone number with the user when the method addContact is used.
-
#share_text ⇒ String
For bots, the text that is included with the link when users share the bot.
Method Summary
Methods inherited from Base
Instance Attribute Details
#bio ⇒ String
A short user bio.
14 15 16 |
# File 'lib/tdlib/types/user_full_info.rb', line 14 def bio @bio end |
#bot_info ⇒ TD::Types::BotInfo?
If the user is a bot, information about the bot; may be null.
14 15 16 |
# File 'lib/tdlib/types/user_full_info.rb', line 14 def bot_info @bot_info end |
#can_be_called ⇒ Boolean
True, if the user can be called.
14 15 16 |
# File 'lib/tdlib/types/user_full_info.rb', line 14 def can_be_called @can_be_called end |
#group_in_common_count ⇒ Integer
Number of group chats where both the other user and the current user are a member; 0 for the current user.
14 15 16 |
# File 'lib/tdlib/types/user_full_info.rb', line 14 def group_in_common_count @group_in_common_count end |
#has_private_calls ⇒ Boolean
True, if the user can't be called due to their privacy settings.
14 15 16 |
# File 'lib/tdlib/types/user_full_info.rb', line 14 def has_private_calls @has_private_calls end |
#is_blocked ⇒ Boolean
True, if the user is blacklisted by the current user.
14 15 16 |
# File 'lib/tdlib/types/user_full_info.rb', line 14 def is_blocked @is_blocked end |
#need_phone_number_privacy_exception ⇒ Boolean
True, if the current user needs to explicitly allow to share their phone number with the user when the method addContact is used.
14 15 16 |
# File 'lib/tdlib/types/user_full_info.rb', line 14 def need_phone_number_privacy_exception @need_phone_number_privacy_exception end |
#share_text ⇒ String
For bots, the text that is included with the link when users share the bot.
14 15 16 |
# File 'lib/tdlib/types/user_full_info.rb', line 14 def share_text @share_text end |